@@ -253,7 +253,7 @@ from xml.sax.handler import ContentHandler
 from xml.sax.saxutils import escape, quoteattr
 from xml.dom.minidom import parseString
 
-__version__ = "0.9.3"
+__version__ = "0.9.4"
 
 __all__ = ['SolrException', 'Solr', 'SolrConnection',
            'Response', 'SearchHandler']
@@ -805,9 +805,15 @@ class SearchHandler(object):
         happens to either input parameters or responses.
         """
         # Clean up optional parameters to match SOLR spec.
-        params = dict([(key.replace('_','.'), value)
-                       for key, value in params.items()])
-        request = urllib.urlencode(params, doseq=True)
+        query = []
+        to_str = lambda s: s.encode('utf-8') if isinstance(s, unicode) else s
+        for key, value in params.items():
+            key = key.replace('_', '.')
+            if isinstance(value, (list, tuple)):
+                query.extend([(key, to_str(v)) for v in value])
+            else:
+                query.append((key, to_str(value)))
+        request = urllib.urlencode(query, doseq=True)
         conn = self.conn
         if conn.debug:
             logging.info("solrpy request: %s" % request)
